@@ -484,7 +484,8 @@ class TrackedAction(ConfiguredAction):
     def as_dict(self) -> dict:
         """dictionary of relevant information"""
         out = {
-            'name': self.name,
+            'name': self.action.name,
+            'configuration_name': self.name,  # todo add configuration name when it's sorted out
             'arguments': self.args,
             'keyword_arguments': self.kwargs,
             'status_code': self.status_code,
@@ -498,7 +499,7 @@ class TrackedAction(ConfiguredAction):
             out['duration'] = self.time_completed - self.time_started
             if self.error is True:
                 out['error_during_execution'] = True
-                out['error_details'] = self.error_details
+                out['error_details'] = str(self.error_details)
             else:  # if completed and no error, include the method return
                 out['action_return'] = self.method_return
         return out
